==> cdktf-cdktf-provider-google_beta-3.0.1.tar.gz: package/lib/google-resource-manager-lien/index.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleResourceManagerLienConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_resource_manager_lien#id GoogleResourceManagerLien#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * A stable, user-visible/meaningful string identifying the origin
  of the Lien, intended to be inspected programmatically. Maximum length of
  200 characters.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_resource_manager_lien#origin GoogleResourceManagerLien#origin}
    */
    readonly origin: string;
    /**
    * A reference to the resource this Lien is attached to.
  The server will validate the parent against those for which Liens are supported.
  Since a variety of objects can have Liens against them, you must provide the type
  prefix (e.g. "projects/my-project-name").
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_resource_manager_lien#parent GoogleResourceManagerLien#parent}
    */
    readonly parent: string;
    /**
    * Concise user-visible strings indicating why an action cannot be performed
  on a resource. Maximum length of 200 characters.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_resource_manager_lien#reason GoogleResourceManagerLien#reason}
    */
    readonly reason: string;
    /**
    * The types of operations which should be blocked as a result of this Lien.
  Each value should correspond to an IAM permission. The server will validate
  the permissions against those for which Liens are supported.  An empty
  list is meaningless and will be rejected.
  e.g. ['resourcemanager.projects.delete']
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_resource_manager_lien#restrictions GoogleResourceManagerLien#restrictions}
    */
    readonly restrictions: string[];
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_resource_manager_lien#timeouts GoogleResourceManagerLien#timeouts}
    */
    readonly timeouts?: GoogleResourceManagerLienTimeouts;
}
export interface GoogleResourceManagerLienTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_resource_manager_lien#create GoogleResourceManagerLien#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_resource_manager_lien#delete GoogleResourceManagerLien#delete}
    */
    readonly delete?: string;
}
export declare function googleResourceManagerLienTimeoutsToTerraform(struct?: GoogleResourceManagerLienTimeoutsOutputReference | GoogleResourceManagerLienTimeouts | cdktf.IResolvable): any;
export declare class GoogleResourceManagerLienTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleResourceManagerLienTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleResourceManagerLienTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_resource_manager_lien google_resource_manager_lien}
*/
export declare class GoogleResourceManagerLien extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_resource_manager_lien";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_resource_manager_lien google_resource_manager_lien} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleResourceManagerLienConfig
    */
    constructor(scope: Construct, id: string, config: GoogleResourceManagerLienConfig);
    get createTime(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get name(): string;
    private _origin?;
    get origin(): string;
    set origin(value: string);
    get originInput(): string | undefined;
    private _parent?;
    get parent(): string;
    set parent(value: string);
    get parentInput(): string | undefined;
    private _reason?;
    get reason(): string;
    set reason(value: string);
    get reasonInput(): string | undefined;
    private _restrictions?;
    get restrictions(): string[];
    set restrictions(value: string[]);
    get restrictionsInput(): string[] | undefined;
    private _timeouts;
    get timeouts(): GoogleResourceManagerLienTimeoutsOutputReference;
    putTimeouts(value: GoogleResourceManagerLienTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleResourceManagerLienTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-google_beta-7.0.0.tar.gz: package/lib/google-resource-manager-lien/index.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleResourceManagerLienConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_resource_manager_lien#id GoogleResourceManagerLien#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * A stable, user-visible/meaningful string identifying the origin
  of the Lien, intended to be inspected programmatically. Maximum length of
  200 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_resource_manager_lien#origin GoogleResourceManagerLien#origin}
    */
    readonly origin: string;
    /**
    * A reference to the resource this Lien is attached to.
  The server will validate the parent against those for which Liens are supported.
  Since a variety of objects can have Liens against them, you must provide the type
  prefix (e.g. "projects/my-project-name").
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_resource_manager_lien#parent GoogleResourceManagerLien#parent}
    */
    readonly parent: string;
    /**
    * Concise user-visible strings indicating why an action cannot be performed
  on a resource. Maximum length of 200 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_resource_manager_lien#reason GoogleResourceManagerLien#reason}
    */
    readonly reason: string;
    /**
    * The types of operations which should be blocked as a result of this Lien.
  Each value should correspond to an IAM permission. The server will validate
  the permissions against those for which Liens are supported.  An empty
  list is meaningless and will be rejected.
  e.g. ['resourcemanager.projects.delete']
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_resource_manager_lien#restrictions GoogleResourceManagerLien#restrictions}
    */
    readonly restrictions: string[];
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_resource_manager_lien#timeouts GoogleResourceManagerLien#timeouts}
    */
    readonly timeouts?: GoogleResourceManagerLienTimeouts;
}
export interface GoogleResourceManagerLienTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_resource_manager_lien#create GoogleResourceManagerLien#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_resource_manager_lien#delete GoogleResourceManagerLien#delete}
    */
    readonly delete?: string;
}
export declare function googleResourceManagerLienTimeoutsToTerraform(struct?: GoogleResourceManagerLienTimeouts | cdktf.IResolvable): any;
export declare class GoogleResourceManagerLienTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleResourceManagerLienTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleResourceManagerLienTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_resource_manager_lien google_resource_manager_lien}
*/
export declare class GoogleResourceManagerLien extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_resource_manager_lien";
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/resources/google_resource_manager_lien google_resource_manager_lien} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleResourceManagerLienConfig
    */
    constructor(scope: Construct, id: string, config: GoogleResourceManagerLienConfig);
    get createTime(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get name(): string;
    private _origin?;
    get origin(): string;
    set origin(value: string);
    get originInput(): string | undefined;
    private _parent?;
    get parent(): string;
    set parent(value: string);
    get parentInput(): string | undefined;
    private _reason?;
    get reason(): string;
    set reason(value: string);
    get reasonInput(): string | undefined;
    private _restrictions?;
    get restrictions(): string[];
    set restrictions(value: string[]);
    get restrictionsInput(): string[] | undefined;
    private _timeouts;
    get timeouts(): GoogleResourceManagerLienTimeoutsOutputReference;
    putTimeouts(value: GoogleResourceManagerLienTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleResourceManagerLienTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
